\c dummy;

CREATE TABLE IF NOT EXISTS employee (
	employee_ID integer primary key not null,
	ssn varchar(11),
	department_ID integer not null,
	super_ssn varchar(11),
	fname varchar(25),
	lname varchar(25),
	dob Date not null,
	start_date Date not null,
	end_date Date not null,
	CONSTRAINT fk_employee_department FOREIGN KEY(department_ID) REFERENCES department(department_ID),
	CONSTRAINT ck_dates CHECK (start_date < end_date)
);

CREATE TABLE IF NOT EXISTS department (
	department_ID integer primary key not null,
	location_ID integer not null,
	type varchar(15),
	CONSTRAINT fk_location_department FOREIGN KEY (location_ID) REFERENCES location(location_ID)
);

CREATE TABLE IF NOT EXISTS location (
	location_ID integer primary key not null,
	street varchar(50),
	city varchar(25),
	state varchar(2),
	zip varchar(5)
);

CREATE TABLE IF NOT EXISTS contract (
	contract_ID integer primary key not null,
	customer_ID integer not null,
	service_type varchar(24),
	cost real default 100.00,
	frequency varchar(24) not null,
	start_date Date not null,
	end_date Date not null,
	CONSTRAINT fk_contract_customer FOREIGN KEY (customer_ID) REFERENCES customer(customer_ID),
	CONSTRAINT ck_contract_dates CHECK (start_date < end_date),
	CONSTRAINT ck_costCheck CHECK (cost > 0.0)
);

CREATE TABLE IF NOT EXISTS customer (
	customer_ID integer primary key not null,
	street varchar(50),
	city varchar(25),
	state varchar(2),
	zip numeric(5),
	fname varchar(25),
	lname varchar(25),
	phone_number varchar(13)
);

CREATE TABLE IF NOT EXISTS property (
	property_ID integer primary key not null,
	contract_ID integer not null,
	customer_ID integer not null,
	next_property_ID integer,
	type varchar(25),
	street varchar(50),
	city varchar(25),
	state varchar(2),
	zip numeric(5),
	latitude real,
	longitude real,
	CONSTRAINT fk_property_contract FOREIGN KEY (contract_ID) REFERENCES contract(contract_ID),
	CONSTRAINT fk_property_customer FOREIGN KEY (customer_ID) REFERENCES customer(customer_ID),
	CONSTRAINT fk_property_property FOREIGN KEY (next_property_ID) REFERENCES property(property_ID)
);

CREATE TABLE IF NOT EXISTS area (
	property_ID integer primary key not null,
	area_size real,
	area_location varchar(30),
	chemicals_used varchar(255),
	CONSTRAINT fk_area_property FOREIGN KEY (property_ID) REFERENCES property(property_ID),
	CONSTRAINT ck_areaCheck CHECK (area_size > 0)
);

CREATE TABLE IF NOT EXISTS route (
	route_ID integer primary key not null,
	property_ID integer not null,
	truck_ID integer not null,
	street varchar(50),
	city varchar(25),
	state varchar(2),
	zip numeric(5),
	start_date Date,
	end_date Date,
	CONSTRAINT fk_route_property FOREIGN KEY (property_ID) REFERENCES property(property_ID),
	CONSTRAINT fk_route_truck FOREIGN KEY (truck_ID) REFERENCES truck(truck_ID),
	CONSTRAINT ck_route_dates CHECK (start_date < end_date)
);

CREATE TABLE IF NOT EXISTS truck (
	truck_ID integer primary key not null,
	employee_ID integer not null,
	VIN varchar(17),
	license_plate varchar(7),
	model varchar(50),
	make varchar(50),
	CONSTRAINT fk_truck_employee FOREIGN KEY (employee_ID) REFERENCES employee(employee_ID)
);

CREATE TABLE IF NOT EXISTS "order" (
	order_ID integer primary key not null,
	cost real not null,
	date_received Date not null,
	quantity integer not null,
	CONSTRAINT ck_orderCost CHECK (cost > 0),
	CONSTRAINT ck_orderQuantity CHECK (quantity > 0)
);

CREATE TABLE IF NOT EXISTS item (
	item_ID integer primary key not null,
	order_ID integer not null,
	type varchar(50),
	quantity_purchased integer not null,
	price real,
	CONSTRAINT fk_item_order FOREIGN KEY (order_ID) REFERENCES "order"(order_ID),
	CONSTRAINT ck_price CHECK (price > 0.0),
	CONSTRAINT ck_quantityItem CHECK (quantity_purchased > 0)
);

CREATE TABLE IF NOT EXISTS supplier (
	supplier_ID integer primary key not null,
	supplier_name varchar(100)
);

CREATE TABLE IF NOT EXISTS fulfills (
	order_ID integer not null,
	supplier_ID integer not null,
	date_of_purchase Date,
	CONSTRAINT fk_fulfills_order FOREIGN KEY (order_ID) REFERENCES "order"(order_ID),
	CONSTRAINT fk_fulfills_supplier FOREIGN KEY (supplier_ID) REFERENCES supplier(supplier_ID)
);

CREATE TABLE IF NOT EXISTS stored_at (
	location_ID integer not null,
	item_ID integer not null,
	quantity integer not null,
	CONSTRAINT fk_stored_location FOREIGN KEY (location_ID) REFERENCES location(location_ID),
	CONSTRAINT fk_stored_item FOREIGN KEY (item_ID) REFERENCES item(item_ID),
	CONSTRAINT storedQuantity CHECK (quantity > 0)
);

CREATE TABLE IF NOT EXISTS used_by (
	employee_ID integer not null,
	item_ID integer not null,
    amount_used integer not null,
    date_used date,
	CONSTRAINT Fk_used_employee FOREIGN KEY (employee_ID) REFERENCES employee(employee_ID),
	CONSTRAINT fk_used_item FOREIGN KEY (item_ID) REFERENCES item(item_ID),
    CONSTRAINT ck_checkAmount CHECK (amount_used >=0)
);

CREATE TABLE IF NOT EXISTS sells (
	employee_ID integer not null,
	contract_ID integer not null,
	CONSTRAINT fk_sells_employee FOREIGN KEY (employee_ID) REFERENCES employee(employee_ID),
	CONSTRAINT fk_sells_contract FOREIGN KEY (contract_ID) REFERENCES contract(contract_ID)
);
